==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiGui/QAccessibleBridge_shell.cpp <==
#include "QAccessibleBridge_shell.h"
#include <QtJambi/Cast>

void deleter_QAccessibleBridge(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAccessibleBridge")
    QAccessibleBridge *_ptr = reinterpret_cast<QAccessibleBridge *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAccessibleBridge_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAccessibleBridge_shell) ); }

jmethodID QAccessibleBridge_shell::__shell_javaMethod(int pos) const { return QAccessibleBridge_shell::__shell()->javaMethod(typeid(QAccessibleBridge), pos); }

// emitting (writeShellConstructor)
QAccessibleBridge_shell::QAccessibleBridge_shell()
    : QAccessibleBridge()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessibleBridge::QAccessibleBridge_shell()", QAccessibleBridge_shell::__shell())
    QAccessibleBridge_shell::__shell()->constructed(typeid(QAccessibleBridge));
}

// emitting (writeShellDestructor)
QAccessibleBridge_shell::~QAccessibleBridge_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAccessibleBridge::~QAccessibleBridge()", QAccessibleBridge_shell::__shell())
    QAccessibleBridge_shell::__shell()->destructed(typeid(QAccessibleBridge));
}

void QAccessibleBridge_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAccessibleBridge_shell*>(ptr)->QAccessibleBridge_shell::__shell()->tryDeleteShell(typeid(QAccessibleBridge));
}

// emitting Virtual overrides (virtualFunctions)
void QAccessibleBridge_shell::notifyAccessibilityUpdate(QAccessibleEvent* event0)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QAccessibleBridge::notifyAccessibilityUpdate(QAccessibleEvent*)", QAccessibleBridge_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAccessibleBridge_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_event0 = qtjambi_cast<jobject>(__jni_env, event0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_event0);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_event0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAccessibleBridge_shell::__shell()->warnForMethod("QAccessibleBridge::notifyAccessibilityUpdate(QAccessibleEvent*)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAccessibleBridge::notifyAccessibilityUpdate(QAccessibleEvent*)");
            } QTJAMBI_TRY_END
        }
    }
}

void QAccessibleBridge_shell::setRootObject(QAccessibleInterface* arg__1)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QAccessibleBridge::setRootObject(QAccessibleInterface*)", QAccessibleBridge_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAccessibleBridge_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_arg__1 = qtjambi_cast<jobject>(__jni_env, arg__1);
                    QtJambiAPI::setJavaOwnership(__jni_env, __java_arg__1);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_arg__1);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAccessibleBridge_shell::__shell()->warnForMethod("QAccessibleBridge::setRootObject(QAccessibleInterface*)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAccessibleBridge::setRootObject(QAccessibleInterface*)");
            } QTJAMBI_TRY_END
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QAccessibleBridge_access::__qt_notifyAccessibilityUpdate_QAccessibleEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QAccessibleEvent* __qt_event0 = QtJambiAPI::objectFromNativeId<QAccessibleEvent>(event0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QAccessibleBridge::notifyAccessibilityUpdate(QAccessibleEvent * event)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QAccessibleBridge::notifyAccessibilityUpdate(QAccessibleEvent * event).";
    } else {
        notifyAccessibilityUpdate(__qt_event0);
    }
}

void QAccessibleBridge_access::__qt_setRootObject_QAccessibleInterface_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QAccessibleInterface* __qt_arg__1 = QtJambiAPI::interfaceFromNativeId<QAccessibleInterface>(arg__1);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QAccessibleBridge::setRootObject(QAccessibleInterface * arg__1)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QAccessibleBridge::setRootObject(QAccessibleInterface * arg__1).";
    } else {
        setRootObject(__qt_arg__1);
    }
}

// emitting (writeConstructors)
// new 
void __qt_construct_QAccessibleBridge_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QAccessibleBridge *__qt_this = new(__qtjambi_ptr) QAccessibleBridge_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QAccessibleBridge_shell
void __qt_destruct_QAccessibleBridge(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAccessibleBridge")
    reinterpret_cast<QAccessibleBridge_shell*>(ptr)->~QAccessibleBridge_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAccessibleBridge::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleBridge_initialize_1native__Lio_qt_gui_QAccessibleBridge_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessibleBridge::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessibleBridge_0, sizeof(QAccessibleBridge_shell), typeid(QAccessibleBridge), true, &deleter_QAccessibleBridge, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAccessibleBridge::notifyAccessibilityUpdate(QAccessibleEvent*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleBridge_00024ConcreteWrapper_notifyAccessibilityUpdate_1native_1QAccessibleEvent_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID event0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QAccessibleBridge *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleBridge>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleBridge::notifyAccessibilityUpdate(QAccessibleEvent*)", __qt_this)
        static_cast<QAccessibleBridge_access*>(__qt_this)->__qt_notifyAccessibilityUpdate_QAccessibleEvent_ptr(__jni_env, __this_nativeId, event0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAccessibleBridge::setRootObject(QAccessibleInterface*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleBridge_00024ConcreteWrapper_setRootObject_1native_1QAccessibleInterface_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QAccessibleBridge *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleBridge>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleBridge::setRootObject(QAccessibleInterface*)", __qt_this)
        static_cast<QAccessibleBridge_access*>(__qt_this)->__qt_setRootObject_QAccessibleInterface_ptr(__jni_env, __this_nativeId, arg__1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAccessibleBridge(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QAccessibleBridge>("QAccessibleBridge", "io/qt/gui/QAccessibleBridge");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "notifyAccessibilityUpdate", "(Lio/qt/gui/QAccessibleEvent;)V", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "setRootObject", "(Lio/qt/gui/QAccessibleInterface;)V", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QAccessibleBridge, {
        ConstructorInfo(&__qt_construct_QAccessibleBridge_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAccessibleBridge);
    registerSizeOfShell(typeId, sizeof(QAccessibleBridge_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiGui/QAccessibleBridge_shell.cpp <==
#include "QAccessibleBridge_shell.h"
#include <QtJambi/Cast>

void deleter_QAccessibleBridge(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAccessibleBridge")
    QAccessibleBridge *_ptr = reinterpret_cast<QAccessibleBridge *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAccessibleBridge_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAccessibleBridge_shell) ); }

jmethodID QAccessibleBridge_oshell::__shell_javaMethod(int pos) const { return QAccessibleBridge_shell::__shell()->javaMethod(typeid(QAccessibleBridge), pos); }

// emitting (writeShellDestructor)
QAccessibleBridge_shell::~QAccessibleBridge_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAccessibleBridge::~QAccessibleBridge()", this)
    QAccessibleBridge_shell::__shell()->destructed(typeid(QAccessibleBridge));
}

// emitting (writeShellConstructor)
QAccessibleBridge_shell::QAccessibleBridge_shell()
    : QAccessibleBridge()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessibleBridge::QAccessibleBridge_shell()", this)
    QAccessibleBridge_shell::__shell()->constructed(typeid(QAccessibleBridge));
}

void QAccessibleBridge_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAccessibleBridge_oshell*>(ptr)->QAccessibleBridge_oshell::__shell()->tryDeleteShell(typeid(QAccessibleBridge));
}

// emitting Virtual overrides (virtualFunctions)
void QAccessibleBridge_oshell::notifyAccessibilityUpdate(QAccessibleEvent* event0)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QAccessibleBridge::notifyAccessibilityUpdate(QAccessibleEvent*)", this)
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAccessibleBridge_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_event0 = qtjambi_cast<jobject>(__jni_env, event0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_event0);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_event0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAccessibleBridge_shell::__shell()->warnForMethod("QAccessibleBridge::notifyAccessibilityUpdate(QAccessibleEvent*)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAccessibleBridge::notifyAccessibilityUpdate(QAccessibleEvent*)");
            } QTJAMBI_TRY_END
        }
    }
}

void QAccessibleBridge_oshell::setRootObject(QAccessibleInterface* arg__1)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QAccessibleBridge::setRootObject(QAccessibleInterface*)", this)
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAccessibleBridge_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_arg__1 = qtjambi_cast<jobject>(__jni_env, arg__1);
                    QtJambiAPI::setJavaOwnership(__jni_env, __java_arg__1);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_arg__1);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAccessibleBridge_shell::__shell()->warnForMethod("QAccessibleBridge::setRootObject(QAccessibleInterface*)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAccessibleBridge::setRootObject(QAccessibleInterface*)");
            } QTJAMBI_TRY_END
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QAccessibleBridge_access::__qt_notifyAccessibilityUpdate_QAccessibleEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QAccessibleEvent* __qt_event0 = QtJambiAPI::objectFromNativeId<QAccessibleEvent>(event0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QAccessibleBridge::notifyAccessibilityUpdate(QAccessibleEvent * event)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QAccessibleBridge::notifyAccessibilityUpdate(QAccessibleEvent * event).";
    } else {
        notifyAccessibilityUpdate(__qt_event0);
    }
}

void QAccessibleBridge_access::__qt_setRootObject_QAccessibleInterface_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QAccessibleInterface* __qt_arg__1 = QtJambiAPI::interfaceFromNativeId<QAccessibleInterface>(arg__1);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QAccessibleBridge::setRootObject(QAccessibleInterface * arg__1)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QAccessibleBridge::setRootObject(QAccessibleInterface * arg__1).";
    } else {
        setRootObject(__qt_arg__1);
    }
}

// emitting (writeConstructors)
// new QAccessibleBridge()
void __qt_construct_QAccessibleBridge(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAccessibleBridge()")
    Q_UNUSED(__java_arguments)
    QAccessibleBridge *__qt_this = new(__qtjambi_ptr) QAccessibleBridge_oshell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QAccessibleBridge::QAccessibleBridge()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleBridge_initialize_1native__Lio_qt_gui_QAccessibleBridge_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessibleBridge::QAccessibleBridge()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessibleBridge, sizeof(QAccessibleBridge_shell), typeid(QAccessibleBridge), 0, true, &deleter_QAccessibleBridge, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QAccessibleBridge_shell
void __qt_destruct_QAccessibleBridge(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAccessibleBridge")
    reinterpret_cast<QAccessibleBridge_shell*>(ptr)->~QAccessibleBridge_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAccessibleBridge::notifyAccessibilityUpdate(QAccessibleEvent*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleBridge_00024ConcreteWrapper_notifyAccessibilityUpdate_1native_1QAccessibleEvent_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID event0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QAccessibleBridge *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleBridge>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleBridge::notifyAccessibilityUpdate(QAccessibleEvent*)", __this_nativeId)
        static_cast<QAccessibleBridge_access*>(__qt_this)->__qt_notifyAccessibilityUpdate_QAccessibleEvent_ptr(__jni_env, __this_nativeId, event0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAccessibleBridge::setRootObject(QAccessibleInterface*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleBridge_00024ConcreteWrapper_setRootObject_1native_1QAccessibleInterface_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QAccessibleBridge *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleBridge>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleBridge::setRootObject(QAccessibleInterface*)", __this_nativeId)
        static_cast<QAccessibleBridge_access*>(__qt_this)->__qt_setRootObject_QAccessibleInterface_ptr(__jni_env, __this_nativeId, arg__1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAccessibleBridge(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QAccessibleBridge>("QAccessibleBridge", "io/qt/gui/QAccessibleBridge");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "notifyAccessibilityUpdate", "(Lio/qt/gui/QAccessibleEvent;)V", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "setRootObject", "(Lio/qt/gui/QAccessibleInterface;)V", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QAccessibleBridge, {
        ConstructorInfo(&__qt_construct_QAccessibleBridge, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAccessibleBridge);
    registerSizeOfShell(typeId, sizeof(QAccessibleBridge_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
